pitchtools.register_pitch_class_numbers_by_pitch_number_aggregate
=================================================================

.. autofunction:: abjad.tools.pitchtools.register_pitch_class_numbers_by_pitch_number_aggregate.register_pitch_class_numbers_by_pitch_number_aggregate
